@@ -11,12 +11,24 @@ import time
 #import re
 import xml.etree.ElementTree as ET
 import osso
-#from mokoui import FingerScroll as FS
 #import hildonhelp
 
+try:
+   from mokoui import FingerScroll as FS
+   MOKO = True
+except ImportError:
+   MOKO = False
+try:
+   from hildon import PannableArea
+   HILDON_KINETIC = True
+except ImportError:
+   HILDON_KINETIC = False
+
 a_name = "Quick Clip Viewer"
-a_version = "0.4.2"
-osso_context = osso.Context('com.quickclip.Viewer','.0.4.2', False)
+a_version = "0.4.4"
+osso_context = osso.Context('com.quickclip.Viewer','.0.4.4', False)
+
+HOME = os.getenv('HOME')
 
 class QuickClipViewer(hildon.Program):
    def __init__(self):
@@ -37,15 +49,14 @@ class QuickClipViewer(hildon.Program):
 
       settings = self.get_settings()
 
-      if settings['scrolling'] == 1:
-         self.sw = gtk.ScrolledWindow()
-         self.sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-      else:
-         from mokoui import FingerScroll as FS
+      if settings['scrolling'] == 'Moko':
          self.sw = FS()
          self.sw.set_property('mode', 1)
-         #self.sw.set_property('deceleration', .1)
-         #self.sw.set_property('sps', 100)
+      elif settings['scrolling'] == 'Hildon':
+         self.sw = hildon.PannableArea()
+      else:
+         self.sw = gtk.ScrolledWindow()
+         self.sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
 
       self.textview = gtk.TextView()
       textbuffer = self.textview.get_buffer()
@@ -520,16 +531,30 @@ class QuickClipViewer(hildon.Program):
       cancel_button = dialog.add_button(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL)
 
       settings = self.get_settings()
-
-      combobox = gtk.combo_box_new_text()
-      combobox.append_text("Kinetic")
-      combobox.append_text("GTK")
-
-      combobox.set_active(int(settings['scrolling']))
+      
+      gtk_button = gtk.RadioButton(None, 'GTK')
+      gtk_button.set_mode(False)
+      hildon_button = gtk.RadioButton(gtk_button, 'Hildon')
+      if HILDON_KINETIC == False:
+         hildon_button.set_sensitive(False)
+      hildon_button.set_mode(False)
+      moko_button = gtk.RadioButton(gtk_button, 'Moko')
+      if MOKO == False:
+         moko_button.set_sensitive(False)
+      moko_button.set_mode(False)
+      
+      if settings['scrolling'] == 'Hildon':
+         hildon_button.set_active(True)
+      elif settings['scrolling'] == 'Moko':
+         moko_button.set_active(True)
+      else:
+         gtk_button.set_active(True)
 
       hbox = gtk.HBox()
       hbox.pack_start(gtk.Label("Scrolling:"), False, 5, 5)
-      hbox.pack_end(combobox)
+      hbox.pack_start(gtk_button)
+      hbox.pack_end(hildon_button)
+      hbox.pack_end(moko_button)
 
       label = gtk.Label()
       label.set_markup("<b>Note:</b> You may need to restart the\nprogram for some changes to take effect.")
@@ -541,8 +566,13 @@ class QuickClipViewer(hildon.Program):
       response = dialog.run()
 
       if response == gtk.RESPONSE_OK:
-         scrolling = combobox.get_active()
-         self.set_settings(None, scrolling)
+         scrolling_buttons = gtk_button.get_group()
+         for button in scrolling_buttons:
+            scrolling = button.get_active()
+            if scrolling == True:
+               label = button.get_label()
+               break
+         self.set_settings(None, label)
 
       dialog.destroy()
 
@@ -551,6 +581,7 @@ class QuickClipViewer(hildon.Program):
    def help(self, widget, data=None):
       import hildonhelp
       hildonhelp.help_show(osso_context, "osso_quickclip_viewer", 0)
+      pass
 
 # About dialog
 
@@ -587,7 +618,7 @@ License along with this program.  If not, see
 
    def get_q_settings(self):
 
-      user_config_file = open('/home/user/.quickclip/quickclip.conf', 'r')
+      user_config_file = open(HOME + '/.quickclip/quickclip.conf', 'r')
       user_config_access = ConfigParser.RawConfigParser()
       user_config_access.readfp(user_config_file)
 
@@ -620,7 +651,7 @@ License along with this program.  If not, see
 # Get parent files
 
    def get_files(self):
-      tree = ET.parse("/home/user/.quickclip/parent_files.xml")
+      tree = ET.parse(HOME + '/.quickclip/parent_files.xml')
       elements = tree.getroot()
       files_list = []
 
@@ -633,14 +664,13 @@ License along with this program.  If not, see
 
    def get_settings(self):
 
-      user_config_file = open('/home/user/.quickclip/viewer.conf', 'r')
+      user_config_file = open(HOME + '/.quickclip/viewer.conf', 'r')
       user_config_access = ConfigParser.RawConfigParser()
       user_config_access.readfp(user_config_file)
 
       settings_dict = {}
       settings_dict['font'] = user_config_access.get('DEFAULT', 'font')
       settings_dict['scrolling'] = user_config_access.get('DEFAULT', 'scrolling')
-      settings_dict['scrolling'] = int(settings_dict['scrolling'])
 
       user_config_file.close()
 
@@ -652,7 +682,7 @@ License along with this program.  If not, see
 
       settings = self.get_settings()
 
-      user_config_file = open('/home/user/.quickclip/viewer.conf', 'w')
+      user_config_file = open(HOME + '/.quickclip/viewer.conf', 'w')
       user_config_access = ConfigParser.RawConfigParser()
 
       if not font == None:
@@ -721,9 +751,9 @@ License along with this program.  If not, see
    def run(self):
       gtk.main()
 
-if not os.path.exists('/home/user/.quickclip/viewer.conf'):
+if not os.path.exists(HOME + '/.quickclip/viewer.conf'):
 
-   user_config_file = open('/home/user/.quickclip/viewer.conf', 'w')
+   user_config_file = open(HOME + '/.quickclip/viewer.conf', 'w')
    user_config_access = ConfigParser.RawConfigParser()
 
    user_config_access.set('DEFAULT', 'font', 'Sans 12')
